Review $ARGUMENTS (if no argument is provided, use `git status` to locate) and
revise it to align with my personal preferences. 

## Audiences and Goals

This writing is intended for a blog post so it should REFLECT MY PERSONAL STYLE
AND TONE and SERVE MY MAIN AUDIENCES' INTERESTS. 

1. Senior software engineers with 20+ years experiences in the field. They are
   either skeptical of drinking the kool-aid, or feeling overwhelmed by the
   amount of information and fast-face of the developments. My goal is to help
   them develop a REALISTIC, UP-TO-DATE, understanding of AI and unstand where the frontier
   is at without sounding too much a fanboy. The tone should be calming and
   reassuring. 

2. C-level executives in their 40-60s or board members in their 50-early 70s.
   They understand that AI is the most important crucial foundation force for
   their business, but they also understand that adopting AI requires careful
   planning and developing and maintaining a strategic roadmap to keep all
   stakeholders aligned. My goal is to keep them informed of the STRATEGIC IMPACT
   ON THE COMPETITIVE LANDSCAPE AND ORGANISATIONAL STRUCTURE. The tone needs to
   be objective, factual, and helpful, without being too technical.

3. New Zealand's Angel Investment network. They are interested in the new kind
   of businesses enabled by AI. But they are also aware that AI is a fast
   -paced field and they need a clear ROI within 5-7 years to make investment
   decisions. My goal is to provide a DETAILED, TIME-BOUNDED, AND FORWARD-LOOKING 
   assessment of opportunities and risks to businesses and industries to aid
   their technical due diligence. The tone should be analytical, succinct but 
   comfortable with ambiguity.

## Before You Start

ULTRATHINK about the following questions and output
a detailed answer to each the questions to guide your revision:

* Who is the audience
* What they need to know
* How to best communicate

## Revision Scope

Ensure that you keep the following content intact:

- Quotes and citations. Texts starting with `>` are quotes and should not be modified.
- Code blocks. Texts starting with ```` are code blocks and should not be modified.
- Feedback blocks starting with `[[[FEEDBACK: ]]]` and ending with `]]]`. 
- Rewrite or delete blocks starting with `/%<---` and ending with `--->%/`.

## Revision Guideline

- Use simple language that is precise, clear, and efficient. 
- Keep the tone to be quietly confident. 
- Maintain a friendly and approachable demeanor. 
- Maintain a conversational, coaching tone that is approachable, supportive, and encouraging.
- Prefer a narrative style that is engaging and relatable over lists or bullet points. 
- Use first person, active voice where appropriate to make the content more personal and engaging.
- Always backup claims with evidence, data, or third-party sources. Use Deep
  Research Tasks to identify and cite relevant sources.
- Keep technical terms and proper nouns intact

- Avoid vague language, like "a lot", "many", "some", etc.
- Avoid hollow superlatives, like "sophisticated", "amazing", "incredible", "fantastic", etc.
- Avoid hyperbolic language, like "flagship", "game-changing", "ground-breaking", etc.
- Avoid unsubstantiated claims, like "the best", "the most", "the only", "the first", etc.
- Avoid condescending language, like "obviously", "clearly", "evidently", etc.
- Avoid repeating the same point multiple times, unless it is necessary for emphasis.
- Avoid filler words or phrases, like "basically", "think of it this way", "at the end of the day", etc.

- Replace weak verbs with stronger alternatives ("gave insights" → "clystalised insights")
- Eliminate redundant phrases ("not uncommon" → "common")
- Improve precision ("hole in the wall" → "vulnerability")
- Streamline awkward constructions ("Then he went on" → "Tao then applies")

## Feedback and Rewrites

There are two types of feedback:

1. Rewrite block: the content surrounded by a pair of `/%<---`
   `--->%/` needs to be either dropped or significantly revised. 

   <rewrite_rule>For your rewrite, provide 3-5 distinct options that are unique
   yet still aligned with the overall tone and style of the post.</rewrite_rule>

2. Feedback block: `[[[FEEDBACK: ]]]` Please carefully consider the feedback with regards to the
content preceeding it. 

- If the feedback requests further research, make sure you include URL and
  citation of the source. It's often a good idea to directly quote the relevant
  part of the source. Make sure you run Tasks to do deep research on the topic.

- If the feedback requests a change in the content, make sure you
  understand the request's intent and implement them accordingly.

  Follow the <rewrite_rule> when you produce the revised content. 

## Revision Process

1. If no file path is provided in $ARGUMENTS, find the most recent blog post in `_posts/`
2. Read the entire post carefully
3. Make improvements in sequence:
   - Fix grammar and spelling errors
   - Improve sentence flow and clarity
   - Enhance word choice for precision
   - Check tense and voice consistency
   - Tighten verbose passages


## Specific Considerations for Titles

When you are asked to provide title options, 

Start with iterating the target audience of the content.

Then initiate a Deep Research Task to understand the keywords and phrases the
target audience might search for. Summarise your findings in a numbered list.
Prioritise by their importance. Focus on search intent instead of piling up
search keywords. 

Lastly, provide 3-5 title options that:

- Leverage the keywords identified in the Deep Research Task
- Clearly signal the structure ("Two Insights from...")
- Set the clear expectation of what the user will gain from reading the post
- Capture the main themes concisely
- Use natural, conversational language

## Specific Considerations for Endings

When you are asked to provide ending options, offer 5 options that:

- Include personal reflection on their work
- Connect back to broader themes in the post
- Provide forward-looking perspective
- Encourage readers to think about their own experiences
- Re-cap the main insights or takeaways Maintain authentic voice that is quietly confident and reflective
